@@ -21,7 +21,7 @@ class AliCloudClient:
                                 endpoint=endpoint)
         return client
 
-    def do_request(self, req_cls, query_params=None, body_params=None):
+    def do_request(self, req_cls, query_params=None, body_params=None, set_params=None):
         req = req_cls()
         if query_params:
             for k, v in query_params.items():
@@ -29,6 +29,9 @@ class AliCloudClient:
         if body_params:
             for k, v in body_params.items():
                 req.add_body_params(k, v)
+        if set_params:
+            for key, value in list(set_params.items()):
+                getattr(req, "set_" + key)(value)
         try:
             res = self.client.do_action_with_exception(req)
         except Exception as e:
