@@ -9,4 +9,4 @@ class HuaweiIamClient(HuaweiClient):
 
     @property
     def iam_client(self):
-        return self.generate_client(IamClient, IamRegion)
+        return self.generate_global_client(IamClient, IamRegion)
